Class: SquareConnect::OrderLineItemDiscount

Inherits:
Object
  • Object
show all
Defined in:
lib/square_connect/models/order_line_item_discount.rb

Overview

Represents a discount that applies to one or more line items in an order. Fixed-amount, order-level discounts are distributed across all non-zero line item totals. The amount distributed to each line item is relative to that item’s contribution to the order subtotal.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OrderLineItemDiscount

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/square_connect/models/order_line_item_discount.rb', line 81

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.has_key?(:'percentage')
    self.percentage = attributes[:'percentage']
  end

  if attributes.has_key?(:'amount_money')
    self.amount_money = attributes[:'amount_money']
  end

  if attributes.has_key?(:'applied_money')
    self.applied_money = attributes[:'applied_money']
  end

  if attributes.has_key?(:'scope')
    self.scope = attributes[:'scope']
  end

end

Instance Attribute Details

#amount_moneyObject

The total monetary amount of the applicable discount. If it is at order level, it is the value of the order level discount. If it is at line item level, it is the value of the line item level discount. The amount_money won’t be set for a percentage-based discount.



25
26
27
# File 'lib/square_connect/models/order_line_item_discount.rb', line 25

def amount_money
  @amount_money
end

#applied_moneyObject

The amount of discount actually applied to this line item. Represents the amount of money applied to a line item as a discount When an amount-based discount is at order-level, this value is different from amount_money because the discount is distributed across the line items.



28
29
30
# File 'lib/square_connect/models/order_line_item_discount.rb', line 28

def applied_money
  @applied_money
end

#nameObject

The discount’s name.



16
17
18
# File 'lib/square_connect/models/order_line_item_discount.rb', line 16

def name
  @name
end

#percentageObject

The percentage of the tax, as a string representation of a decimal number. A value of 7.25 corresponds to a percentage of 7.25%. The percentage won’t be set for an amount-based discount.



22
23
24
# File 'lib/square_connect/models/order_line_item_discount.rb', line 22

def percentage
  @percentage
end

#scopeObject

Indicates the level at which the discount applies. See [OrderLineItemDiscountScope](#type-orderlineitemdiscountscope) for possible values.



31
32
33
# File 'lib/square_connect/models/order_line_item_discount.rb', line 31

def scope
  @scope
end

#typeObject

The type of the discount. If it is created by API, it would be either FIXED_PERCENTAGE or FIXED_AMOUNT. VARIABLE_* is not supported in API because the order is created at the time of sale and either percentage or amount has to be specified. See [OrderLineItemDiscountType](#type-orderlineitemdiscounttype) for possible values.



19
20
21
# File 'lib/square_connect/models/order_line_item_discount.rb', line 19

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
# File 'lib/square_connect/models/order_line_item_discount.rb', line 56

def self.attribute_map
  {
    :'name' => :'name',
    :'type' => :'type',
    :'percentage' => :'percentage',
    :'amount_money' => :'amount_money',
    :'applied_money' => :'applied_money',
    :'scope' => :'scope'
  }
end

.swagger_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
# File 'lib/square_connect/models/order_line_item_discount.rb', line 68

def self.swagger_types
  {
    :'name' => :'String',
    :'type' => :'String',
    :'percentage' => :'String',
    :'amount_money' => :'Money',
    :'applied_money' => :'Money',
    :'scope' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



152
153
154
155
156
157
158
159
160
161
# File 'lib/square_connect/models/order_line_item_discount.rb', line 152

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      type == o.type &&
      percentage == o.percentage &&
      amount_money == o.amount_money &&
      applied_money == o.applied_money &&
      scope == o.scope
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/square_connect/models/order_line_item_discount.rb', line 199

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = SquareConnect.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/square_connect/models/order_line_item_discount.rb', line 265

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/square_connect/models/order_line_item_discount.rb', line 178

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


165
166
167
# File 'lib/square_connect/models/order_line_item_discount.rb', line 165

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



171
172
173
# File 'lib/square_connect/models/order_line_item_discount.rb', line 171

def hash
  [name, type, percentage, amount_money, applied_money, scope].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



115
116
117
118
# File 'lib/square_connect/models/order_line_item_discount.rb', line 115

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



245
246
247
# File 'lib/square_connect/models/order_line_item_discount.rb', line 245

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



251
252
253
254
255
256
257
258
259
# File 'lib/square_connect/models/order_line_item_discount.rb', line 251

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



239
240
241
# File 'lib/square_connect/models/order_line_item_discount.rb', line 239

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



122
123
124
125
126
127
128
# File 'lib/square_connect/models/order_line_item_discount.rb', line 122

def valid?
  type_validator = EnumAttributeValidator.new('String', ["UNKNOWN", "FIXED_PERCENTAGE", "FIXED_AMOUNT", "VARIABLE_PERCENTAGE", "VARIABLE_AMOUNT"])
  return false unless type_validator.valid?(@type)
  scope_validator = EnumAttributeValidator.new('String', ["LINE_ITEM", "ORDER"])
  return false unless scope_validator.valid?(@scope)
  return true
end