Class: SquareConnect::Tender

Inherits:
Object
  • Object
show all
Defined in:
lib/square_connect/models/tender.rb

Overview

Represents a tender (i.e., a method of payment) used in a Square transaction.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Tender

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/square_connect/models/tender.rb', line 106

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'location_id')
    self.location_id = attributes[:'location_id']
  end

  if attributes.has_key?(:'transaction_id')
    self.transaction_id = attributes[:'transaction_id']
  end

  if attributes.has_key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.has_key?(:'note')
    self.note = attributes[:'note']
  end

  if attributes.has_key?(:'amount_money')
    self.amount_money = attributes[:'amount_money']
  end

  if attributes.has_key?(:'processing_fee_money')
    self.processing_fee_money = attributes[:'processing_fee_money']
  end

  if attributes.has_key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.has_key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.has_key?(:'card_details')
    self.card_details = attributes[:'card_details']
  end

  if attributes.has_key?(:'cash_details')
    self.cash_details = attributes[:'cash_details']
  end

end

Instance Attribute Details

#amount_moneyObject

The amount of the tender.



31
32
33
# File 'lib/square_connect/models/tender.rb', line 31

def amount_money
  @amount_money
end

#card_detailsObject

The details of the card tender. This value is present only if the value of type is CARD.



43
44
45
# File 'lib/square_connect/models/tender.rb', line 43

def card_details
  @card_details
end

#cash_detailsObject

The details of the cash tender. This value is present only if the value of type is CASH.



46
47
48
# File 'lib/square_connect/models/tender.rb', line 46

def cash_details
  @cash_details
end

#created_atObject

The time when the tender was created, in RFC 3339 format.



25
26
27
# File 'lib/square_connect/models/tender.rb', line 25

def created_at
  @created_at
end

#customer_idObject

If the tender is associated with a customer or represents a customer’s card on file, this is the ID of the associated customer.



37
38
39
# File 'lib/square_connect/models/tender.rb', line 37

def customer_id
  @customer_id
end

#idObject

The tender’s unique ID.



16
17
18
# File 'lib/square_connect/models/tender.rb', line 16

def id
  @id
end

#location_idObject

The ID of the transaction’s associated location.



19
20
21
# File 'lib/square_connect/models/tender.rb', line 19

def location_id
  @location_id
end

#noteObject

An optional note associated with the tender at the time of payment.



28
29
30
# File 'lib/square_connect/models/tender.rb', line 28

def note
  @note
end

#processing_fee_moneyObject

The amount of any Square processing fees applied to the tender. This field is not immediately populated when a new transaction is created. It is usually available after about ten seconds.



34
35
36
# File 'lib/square_connect/models/tender.rb', line 34

def processing_fee_money
  @processing_fee_money
end

#transaction_idObject

The ID of the tender’s associated transaction.



22
23
24
# File 'lib/square_connect/models/tender.rb', line 22

def transaction_id
  @transaction_id
end

#typeObject

The type of tender, such as CARD or CASH.



40
41
42
# File 'lib/square_connect/models/tender.rb', line 40

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/square_connect/models/tender.rb', line 71

def self.attribute_map
  {
    :'id' => :'id',
    :'location_id' => :'location_id',
    :'transaction_id' => :'transaction_id',
    :'created_at' => :'created_at',
    :'note' => :'note',
    :'amount_money' => :'amount_money',
    :'processing_fee_money' => :'processing_fee_money',
    :'customer_id' => :'customer_id',
    :'type' => :'type',
    :'card_details' => :'card_details',
    :'cash_details' => :'cash_details'
  }
end

.swagger_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/square_connect/models/tender.rb', line 88

def self.swagger_types
  {
    :'id' => :'String',
    :'location_id' => :'String',
    :'transaction_id' => :'String',
    :'created_at' => :'String',
    :'note' => :'String',
    :'amount_money' => :'Money',
    :'processing_fee_money' => :'Money',
    :'customer_id' => :'String',
    :'type' => :'String',
    :'card_details' => :'TenderCardDetails',
    :'cash_details' => :'TenderCashDetails'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/square_connect/models/tender.rb', line 190

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      location_id == o.location_id &&
      transaction_id == o.transaction_id &&
      created_at == o.created_at &&
      note == o.note &&
      amount_money == o.amount_money &&
      processing_fee_money == o.processing_fee_money &&
      customer_id == o.customer_id &&
      type == o.type &&
      card_details == o.card_details &&
      cash_details == o.cash_details
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/square_connect/models/tender.rb', line 242

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = SquareConnect.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/square_connect/models/tender.rb', line 308

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/square_connect/models/tender.rb', line 221

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


208
209
210
# File 'lib/square_connect/models/tender.rb', line 208

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



214
215
216
# File 'lib/square_connect/models/tender.rb', line 214

def hash
  [id, location_id, transaction_id, created_at, note, amount_money, processing_fee_money, customer_id, type, card_details, cash_details].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



160
161
162
163
164
165
166
167
# File 'lib/square_connect/models/tender.rb', line 160

def list_invalid_properties
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push("invalid value for 'type', type cannot be nil.")
  end

  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



288
289
290
# File 'lib/square_connect/models/tender.rb', line 288

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



294
295
296
297
298
299
300
301
302
# File 'lib/square_connect/models/tender.rb', line 294

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



282
283
284
# File 'lib/square_connect/models/tender.rb', line 282

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



171
172
173
174
175
176
# File 'lib/square_connect/models/tender.rb', line 171

def valid?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["CARD", "CASH", "THIRD_PARTY_CARD", "SQUARE_GIFT_CARD", "NO_SALE", "OTHER"])
  return false unless type_validator.valid?(@type)
  return true
end