Class: SquareConnect::V1Variation
- Inherits:
-
Object
- Object
- SquareConnect::V1Variation
- Defined in:
- lib/square_connect/models/v1_variation.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#id ⇒ Object
The item variation’s unique ID.
-
#inventory_alert_threshold ⇒ Object
If the inventory quantity for the variation is less than or equal to this value and inventory_alert_type is LOW_QUANTITY, the variation displays an alert in the merchant dashboard.
-
#inventory_alert_type ⇒ Object
Indicates whether the item variation displays an alert when its inventory quantity is less than or equal to its inventory_alert_threshold.
-
#item_id ⇒ Object
The ID of the variation’s associated item.
-
#name ⇒ Object
The item variation’s name.
-
#price_money ⇒ Object
The item variation’s price, if any.
-
#pricing_type ⇒ Object
Indicates whether the item variation’s price is fixed or determined at the time of sale.
-
#sku ⇒ Object
The item variation’s SKU, if any.
-
#track_inventory ⇒ Object
If true, inventory tracking is active for the variation.
-
#user_data ⇒ Object
Arbitrary metadata associated with the variation.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1Variation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1Variation
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/square_connect/models/v1_variation.rb', line 101 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'item_id') self.item_id = attributes[:'item_id'] end if attributes.has_key?(:'pricing_type') self.pricing_type = attributes[:'pricing_type'] end if attributes.has_key?(:'price_money') self.price_money = attributes[:'price_money'] end if attributes.has_key?(:'sku') self.sku = attributes[:'sku'] end if attributes.has_key?(:'track_inventory') self.track_inventory = attributes[:'track_inventory'] end if attributes.has_key?(:'inventory_alert_type') self.inventory_alert_type = attributes[:'inventory_alert_type'] end if attributes.has_key?(:'inventory_alert_threshold') self.inventory_alert_threshold = attributes[:'inventory_alert_threshold'] end if attributes.has_key?(:'user_data') self.user_data = attributes[:'user_data'] end end |
Instance Attribute Details
#id ⇒ Object
The item variation’s unique ID.
16 17 18 |
# File 'lib/square_connect/models/v1_variation.rb', line 16 def id @id end |
#inventory_alert_threshold ⇒ Object
If the inventory quantity for the variation is less than or equal to this value and inventory_alert_type is LOW_QUANTITY, the variation displays an alert in the merchant dashboard.
40 41 42 |
# File 'lib/square_connect/models/v1_variation.rb', line 40 def inventory_alert_threshold @inventory_alert_threshold end |
#inventory_alert_type ⇒ Object
Indicates whether the item variation displays an alert when its inventory quantity is less than or equal to its inventory_alert_threshold.
37 38 39 |
# File 'lib/square_connect/models/v1_variation.rb', line 37 def inventory_alert_type @inventory_alert_type end |
#item_id ⇒ Object
The ID of the variation’s associated item.
22 23 24 |
# File 'lib/square_connect/models/v1_variation.rb', line 22 def item_id @item_id end |
#name ⇒ Object
The item variation’s name.
19 20 21 |
# File 'lib/square_connect/models/v1_variation.rb', line 19 def name @name end |
#price_money ⇒ Object
The item variation’s price, if any.
28 29 30 |
# File 'lib/square_connect/models/v1_variation.rb', line 28 def price_money @price_money end |
#pricing_type ⇒ Object
Indicates whether the item variation’s price is fixed or determined at the time of sale.
25 26 27 |
# File 'lib/square_connect/models/v1_variation.rb', line 25 def pricing_type @pricing_type end |
#sku ⇒ Object
The item variation’s SKU, if any.
31 32 33 |
# File 'lib/square_connect/models/v1_variation.rb', line 31 def sku @sku end |
#track_inventory ⇒ Object
If true, inventory tracking is active for the variation.
34 35 36 |
# File 'lib/square_connect/models/v1_variation.rb', line 34 def track_inventory @track_inventory end |
#user_data ⇒ Object
Arbitrary metadata associated with the variation. Cannot exceed 255 characters.
43 44 45 |
# File 'lib/square_connect/models/v1_variation.rb', line 43 def user_data @user_data end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/square_connect/models/v1_variation.rb', line 68 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'item_id' => :'item_id', :'pricing_type' => :'pricing_type', :'price_money' => :'price_money', :'sku' => :'sku', :'track_inventory' => :'track_inventory', :'inventory_alert_type' => :'inventory_alert_type', :'inventory_alert_threshold' => :'inventory_alert_threshold', :'user_data' => :'user_data' } end |
.swagger_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/square_connect/models/v1_variation.rb', line 84 def self.swagger_types { :'id' => :'String', :'name' => :'String', :'item_id' => :'String', :'pricing_type' => :'String', :'price_money' => :'V1Money', :'sku' => :'String', :'track_inventory' => :'BOOLEAN', :'inventory_alert_type' => :'String', :'inventory_alert_threshold' => :'Integer', :'user_data' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/square_connect/models/v1_variation.rb', line 188 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && item_id == o.item_id && pricing_type == o.pricing_type && price_money == o.price_money && sku == o.sku && track_inventory == o.track_inventory && inventory_alert_type == o.inventory_alert_type && inventory_alert_threshold == o.inventory_alert_threshold && user_data == o.user_data end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/square_connect/models/v1_variation.rb', line 239 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = SquareConnect.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/square_connect/models/v1_variation.rb', line 305 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/square_connect/models/v1_variation.rb', line 218 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
205 206 207 |
# File 'lib/square_connect/models/v1_variation.rb', line 205 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
211 212 213 |
# File 'lib/square_connect/models/v1_variation.rb', line 211 def hash [id, name, item_id, pricing_type, price_money, sku, track_inventory, inventory_alert_type, inventory_alert_threshold, user_data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 |
# File 'lib/square_connect/models/v1_variation.rb', line 151 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
285 286 287 |
# File 'lib/square_connect/models/v1_variation.rb', line 285 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
291 292 293 294 295 296 297 298 299 |
# File 'lib/square_connect/models/v1_variation.rb', line 291 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
279 280 281 |
# File 'lib/square_connect/models/v1_variation.rb', line 279 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
158 159 160 161 162 163 164 |
# File 'lib/square_connect/models/v1_variation.rb', line 158 def valid? pricing_type_validator = EnumAttributeValidator.new('String', ["FIXED_PRICING", "VARIABLE_PRICING"]) return false unless pricing_type_validator.valid?(@pricing_type) inventory_alert_type_validator = EnumAttributeValidator.new('String', ["LOW_QUANTITY", "NONE", "INVESTMENT", "LOAN", "SAVINGS", "OTHER"]) return false unless inventory_alert_type_validator.valid?(@inventory_alert_type) return true end |